class: Workflow
cwlVersion: v1.2
id: prep
label: prep
inputs:
  - id: msin
    type: 'Directory[]'
  - id: filter_baselines
    type: string?
    default: '*&'
  - id: raw_data
    type: boolean?
    default: false
  - id: propagatesolutions
    type: boolean?
    default: true
  - id: flagunconverged
    type: boolean?
    default: false
  - id: demix
    type: boolean?
    default: false
  - id: max_dppp_threads
    type: int?
    default: 10
  - id: memoryperc
    type: int?
    default: 20
  - id: flag_baselines
    type: 'string[]?'
    default: []
  - id: avg_timeresolution
    type: int?
    default: 4
  - id: avg_freqresolution
    type: string?
    default: '48.82kHz'
  - id: process_baselines_cal
    type: string?
    default: '*&'
  - id: demix_timestep
    type: int?
    default: 10
  - id: demix_freqstep
    type: int?
    default: 16
  - id: demix_target
    type: string?
    default: ''
  - id: demix_sources
    type: 'string[]?'
    default: []
  - id: min_length
    type: int?
    default: 50
  - id: overhead
    type: float?
    default: 0.8
  - id: min_separation
    type: int?
    default: 30
  - id: do_smooth
    type: boolean?
    default: false
  - id: max_separation_arcmin
    type: float?
    default: 1.0
  - id: calibrator_path_skymodel
    type: Directory?
  - id: A-Team_skymodel
    type: File?
  - id: elevation
    type: string?
    default: 0deg..15deg
  - id: amplmin
    type: float?
    default: 1.e-30
outputs:
  - id: outh5parm
    outputSource:
      - h5parm_collector/outh5parm
    type: File
  - id: check_Ateam_separation.png
    outputSource:
      - check_ateam_separation/output_imag
    type: File
  - id: msout
    outputSource:
      - predict_calibrate/msout
    type: 'Directory[]'
  - id: calibrator_name
    outputSource:
      - find_skymodel_cal/model_name
    type: string
  - id: outh5parm_logfile
    outputSource:
      - h5parm_collector/log
    type: 'File[]'
  - id: check_Ateam_separation.json
    outputSource:
      - check_ateam_separation/output_json
    type: File
  - id: flagged_fraction_dict_refant
    outputSource:
      - predict_calibrate/flagged_fraction_dict
    type: string[]
  - id: flagged_fraction_dict
    outputSource:
      - ndppp_prep_cal/flagged_fraction_dict
    type: string[]
  - id: logfiles
    outputSource:
      - concat_logfiles_calib/output
      - ms_concat/logfile
      - concat_logfiles_predict/output
      - concat_logfiles_blsmooth/output
      - make_sourcedb/log
      - find_skymodel_cal/logfile
      - concat_logfiles_prep_cal/output
      - make_sourcedb_ateam/log
      - check_ateam_separation/logfile
      - aoflag/logfile
    type: 'File[]'
    linkMerge: merge_flattened
steps:
  - id: select
    in:
      - id: input
        source:
          - msin
    out:
      - id: output
    run: ../../steps/selectfirstdirectory.cwl
    label: select_only_first
  - id: ndppp_prep_cal
    in:
      - id: baselines_to_flag
        default: []
        source:
          - flag_baselines
      - id: elevation_to_flag
        source: elevation
      - id: min_amplitude_to_flag
        source: amplmin
      - id: memoryperc
        default: 20
        source: memoryperc
      - id: raw_data
        default: false
        source: raw_data
      - id: demix
        default: false
        source: demix
      - id: msin
        linkMerge: merge_flattened
        source:
          - msin
      - id: msin_baseline
        default: '*'
        source: filter_baselines
      - id: skymodel
        source: make_sourcedb_ateam/sourcedb
      - id: timeresolution
        default: 1
        source: avg_timeresolution
      - id: freqresolution
        default: 12.21kHz
        source: avg_freqresolution
      - id: demix_timestep
        default: 1
        source: demix_timestep
      - id: demix_freqstep
        default: 1
        source: demix_freqstep
      - id: demix_baseline
        default: '*'
        source: process_baselines_cal
      - id: target_source
        source: demix_target
      - id: ntimechunk
        default: 10
        source: max_dppp_threads
      - id: subtract_sources
        source:
          - demix_sources
    out:
      - id: msout
      - id: flagged_fraction_dict
      - id: logfile
    run: .//ndppp_prep_cal.cwl
    label: ndppp_prep_cal
    scatter:
      - msin
  - id: predict_calibrate
    in:
      - id: msin
        linkMerge: merge_flattened
        source:
          - aoflag/output_ms
      - id: do_smooth
        source: do_smooth
      - id: sourcedb
        source: make_sourcedb/sourcedb
      - id: flagunconverged
        source: flagunconverged
      - id: propagatesolutions
        source: propagatesolutions
    out:
      - id: msout
      - id: BLsmooth.log
      - id: predict_cal.log
      - id: calib_cal.log
      - id: flagged_fraction_dict
      - id: outh5parm
    run: .//predict_calibrate.cwl
    label: predict_calibrate
    scatter:
      - msin
  - id: ms_concat
    in:
      - id: min_length
        source: min_length
      - id: overhead
        source: overhead
      - id: msin
        linkMerge: merge_flattened
        source:
          - ndppp_prep_cal/msout
    out:
      - id: concat_meta_ms
      - id: concat_additional_ms
      - id: ms_outs
      - id: logfile
    run: ../../steps/ms_concat.cwl
    label: ms_concat
  - id: aoflag
    in:
      - id: msin
        linkMerge: merge_flattened
        source:
          - ndppp_prep_cal/msout
      - id: concat_meta_ms
        source: ms_concat/concat_meta_ms
      - id: concat_additional_ms
        source: ms_concat/concat_additional_ms
      - id: verbose
        default: true
      - id: combine-spws
        default: true
    out:
      - id: output_ms
      - id: logfile
    run: ../../steps/aoflag.cwl
    label: aoflag
  - id: check_ateam_separation
    in:
      - id: ms
        source:
          - select/output
      - id: min_separation
        source: min_separation
    out:
      - id: output_imag
      - id: output_json
      - id: logfile
    run: ../../steps/check_ateam_separation.cwl
    label: check_Ateam_separation
  - id: make_sourcedb_ateam
    in:
      - id: sky_model
        source: A-Team_skymodel
      - id: logname
        default: make_sourcedb_ateam.log
    out:
      - id: sourcedb
      - id: log
    run: ../../steps/makesourcedb.cwl
    label: make_sourcedb_ateam
  - id: find_skymodel_cal
    in:
      - id: msin
        source:
          - select/output
      - id: skymodels
        source: calibrator_path_skymodel
      - id: max_separation_arcmin
        source: max_separation_arcmin
    out:
      - id: output_models
      - id: model_name
      - id: logfile
    run: ../../steps/find_skymodel_cal.cwl
    label: find_skymodel_cal
  - id: make_sourcedb
    in:
      - id: sky_model
        source: find_skymodel_cal/output_models
      - id: output_file_name
        default: calibrator.sourcedb
    out:
      - id: sourcedb
      - id: log
    run: ../../steps/makesourcedb.cwl
    label: make_sourcedb
  - id: concat_logfiles_prep_cal
    in:
      - id: file_list
        linkMerge: merge_flattened
        source:
          - ndppp_prep_cal/logfile
      - id: file_prefix
        default: ndppp_prep_cal
    out:
      - id: output
    run: ../../steps/concatenate_files.cwl
    label: concat_logfiles_prep_cal
  - id: concat_logfiles_blsmooth
    in:
      - id: file_list
        source:
          - predict_calibrate/BLsmooth.log
      - id: file_prefix
        default: blsmooth_prep
    out:
      - id: output
    run: ../../steps/concatenate_files.cwl
    label: concat_logfiles_blsmooth
  - id: concat_logfiles_predict
    in:
      - id: file_list
        linkMerge: merge_flattened
        source:
          - predict_calibrate/predict_cal.log
      - id: file_prefix
        default: predict_cal
    out:
      - id: output
    run: ../../steps/concatenate_files.cwl
    label: concat_logfiles_predict
  - id: concat_logfiles_calib
    in:
      - id: file_list
        source:
          - predict_calibrate/calib_cal.log
      - id: file_prefix
        default: calib_cal_prep
    out:
      - id: output
    run: ../../steps/concatenate_files.cwl
    label: concat_logfiles_calib
  - id: h5parm_collector
    in:
      - id: h5parmFiles
        source:
          - predict_calibrate/outh5parm
      - id: squeeze
        default: true
      - id: verbose
        default: true
      - id: clobber
        default: true
    out:
      - id: outh5parm
      - id: log
    run: ../../steps/H5ParmCollector.cwl
    label: H5parm_collector

requirements:
  - class: InlineJavascriptRequirement
  - class: StepInputExpressionRequirement
  - class: SubworkflowFeatureRequirement
  - class: ScatterFeatureRequirement
